@@ -7,6 +7,7 @@
 from .base import OsduBaseCredential
 from .environment import OsduEnvironmentCredential
 from .msal_interactive import OsduMsalInteractiveCredential
+from .msal_non_interactive import OsduMsalNonInteractiveCredential
 from .token import OsduTokenCredential
 
 __all__ = [
@@ -14,4 +15,5 @@ __all__ = [
     "OsduEnvironmentCredential",
     "OsduTokenCredential",
     "OsduMsalInteractiveCredential",
+    "OsduMsalNonInteractiveCredential"
 ]
